[svn:parrot] r36550 - in trunk: include/parrot src src/gc

cotto at svn.parrot.org cotto at svn.parrot.org
Tue Feb 10 17:42:39 UTC 2009


Author: cotto
Date: Tue Feb 10 17:42:39 2009
New Revision: 36550
URL: https://trac.parrot.org/parrot/changeset/36550

Log:
[gc] update names of dod_runs, dod_blocks and dod_time

Modified:
   trunk/include/parrot/interpreter.h
   trunk/include/parrot/resources.h
   trunk/src/gc/api.c
   trunk/src/gc/generational_ms.c
   trunk/src/gc/incremental_ms.c
   trunk/src/gc/mark_sweep.c
   trunk/src/inter_misc.c
   trunk/src/pmc_freeze.c
   trunk/src/runops_cores.c

Modified: trunk/include/parrot/interpreter.h
==============================================================================
--- trunk/include/parrot/interpreter.h	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/include/parrot/interpreter.h	Tue Feb 10 17:42:39 2009	(r36550)
@@ -172,7 +172,7 @@
 
 typedef struct _RunProfile {
     FLOATVAL starttime;
-    FLOATVAL dod_time;
+    FLOATVAL gc_time;
     opcode_t cur_op;
     ProfData *data;
 } RunProfile;

Modified: trunk/include/parrot/resources.h
==============================================================================
--- trunk/include/parrot/resources.h	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/include/parrot/resources.h	Tue Feb 10 17:42:39 2009	(r36550)
@@ -141,7 +141,7 @@
     /*
      * statistics for DOD and GC
      */
-    size_t  dod_runs;           /* Number of times we've done a DOD sweep */
+    size_t  gc_runs;           /* Number of times we've done a DOD sweep */
     size_t  lazy_gc_runs;       /* Number of successful lazy DOD sweep */
     size_t  collect_runs;       /* Number of times we've
                                  * done a memory compaction

Modified: trunk/src/gc/api.c
==============================================================================
--- trunk/src/gc/generational_ms.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/gc/generational_ms.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -1863,7 +1863,7 @@
     }
 
     /* normal or lazy DOD run */
-    arena_base->dod_runs++;
+    arena_base->gc_runs++;
     arena_base->lazy_gc = (flags & GC_lazy_FLAG);
     gc_gms_init_mark(interp);
     if (gc_gms_trace_root(interp, !arena_base->lazy_gc) &&

Modified: trunk/src/gc/incremental_ms.c
==============================================================================
--- trunk/src/gc/incremental_ms.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/gc/incremental_ms.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -980,7 +980,7 @@
             (void)parrot_gc_ims_collect(interp, 0);
             break;
         case GC_IMS_FINISHED:
-            ++arena_base->dod_runs;
+            ++arena_base->gc_runs;
             g_ims->state = GC_IMS_CONSUMING;
             /* fall through */
         case GC_IMS_CONSUMING:
@@ -1049,7 +1049,7 @@
     }
 
     /* make the test happy that checks the count ;) */
-    arena_base->dod_runs++;
+    arena_base->gc_runs++;
 
     lazy = flags & GC_lazy_FLAG;
 

Modified: trunk/src/gc/mark_sweep.c
==============================================================================
--- trunk/src/gc/mark_sweep.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/gc/mark_sweep.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -236,7 +236,7 @@
     }
 
     /* Note it */
-    arena_base->dod_runs++;
+    arena_base->gc_runs++;
     --arena_base->DOD_block_level;
 
     return;

Modified: trunk/src/inter_misc.c
==============================================================================
--- trunk/src/inter_misc.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/inter_misc.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -246,7 +246,7 @@
             ret = arena_base->memory_allocated;
             break;
         case DOD_RUNS:
-            ret = arena_base->dod_runs;
+            ret = arena_base->gc_runs;
             break;
         case LAZY_DOD_RUNS:
             ret = arena_base->lazy_gc_runs;

Modified: trunk/src/pmc_freeze.c
==============================================================================
--- trunk/src/pmc_freeze.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/pmc_freeze.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -1823,7 +1823,7 @@
 {
     ASSERT_ARGS(run_thaw)
     visit_info info;
-    int dod_block = 0;
+    int gc_block = 0;
     const UINTVAL bufused = image->bufused;
 
     info.image = image;
@@ -1842,7 +1842,7 @@
         Parrot_do_gc_run(interp, 1);
         Parrot_block_GC_mark(interp);
         Parrot_block_GC_sweep(interp);
-        dod_block = 1;
+        gc_block = 1;
     }
 
     info.what = what;   /* _NORMAL or _CONSTANTS */
@@ -1863,7 +1863,7 @@
     image->bufused = bufused;
     PARROT_ASSERT(image->strstart >= (char *)PObj_bufstart(image));
 
-    if (dod_block) {
+    if (gc_block) {
         Parrot_unblock_GC_mark(interp);
         Parrot_unblock_GC_sweep(interp);
     }

Modified: trunk/src/runops_cores.c
==============================================================================
--- trunk/src/runops_cores.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/runops_cores.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -350,7 +350,7 @@
     Arenas * const arena_base = interp->arena_base;
     Interp *debugger;
 
-    dod = arena_base->dod_runs;
+    dod = arena_base->gc_runs;
     gc = arena_base->collect_runs;
     if (interp->pdb) {
         debugger = interp->pdb->debugger;
@@ -398,8 +398,8 @@
         DO_OP(pc, interp);
         trace_op(interp, code_start, code_end, pc);
 
-        if (dod != arena_base->dod_runs) {
-            dod = arena_base->dod_runs;
+        if (dod != arena_base->gc_runs) {
+            dod = arena_base->gc_runs;
             Parrot_io_eprintf(debugger, "       DOD\n");
         }
 


More information about the parrot-commits mailing list
--- trunk/src/gc/api.c	Tue Feb 10 17:37:40 2009	(r36549)
+++ trunk/src/gc/api.c	Tue Feb 10 17:42:39 2009	(r36550)
@@ -436,7 +436,7 @@
 {
     ASSERT_ARGS(Parrot_gc_profile_start)
     if (Interp_flags_TEST(interp, PARROT_PROFILE_FLAG))
-        interp->profile->dod_time = Parrot_floatval_time();
+        interp->profile->gc_time = Parrot_floatval_time();
 }
 
 /*
@@ -459,18 +459,18 @@
         const FLOATVAL     now     = Parrot_floatval_time();
 
         profile->data[what].numcalls++;
-        profile->data[what].time += now - profile->dod_time;
+        profile->data[what].time += now - profile->gc_time;
 
         /*
          * we've recorded the time of a DOD/GC piece from
          * dod_time until now, so add this to the start of the
          * currently executing opcode, which hasn't run this
          * interval.
          */
-        profile->starttime += now - profile->dod_time;
+        profile->starttime += now - profile->gc_time;
 
         /* prepare start for next step */
-        profile->dod_time   = now;
+        profile->gc_time    = now;
     }
 }
 
@@ -459,18 +459,18 @@
         /*
          * we've recorded the time of a DOD/GC piece from
-         * dod_time until now, so add this to the start of the
+         * gc_time until now, so add this to the start of the
          * currently executing opcode, which hasn't run this
          * interval.

Modified: trunk/src/gc/generational_ms.c
==============================================================================